@@ -2,7 +2,7 @@ import click
 
 from agileupstate.client import get_version_string
 from agileupstate.terminal import print_check_message, print_cross_message
-from agileupstate.vault import address, is_ready, create_state
+from agileupstate.vault import address, is_ready, create_state, load_state, create_tfstate
 
 CONTEXT_SETTINGS = dict(help_option_names=['-h', '--help'])
 
@@ -33,8 +33,13 @@ def create() -> None:
 
 
 @cli.command(help='Update client state.')
-def update() -> None:
-    click.secho('- Update client state', fg='green')
+@click.option('--config-type', required=True, type=click.Choice(['TERRAFORM', 'ANSIBLE'], case_sensitive=True),
+              help='Choose required configuration framework')
+def update(config_type) -> None:
+    click.secho(f'- Update client state for config {config_type}', fg='green')
+    state = load_state()
+    tfstate_content = state.tfstate(file='resources/tests/terraform.tfstate')
+    create_tfstate(state, tfstate_content)
 
 
 @cli.command(help='Save client state.')
